Detector Operations
===================

.. currentmodule:: pynrc

.. rubric:: Classes

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:
   
   DetectorOps
   multiaccum


.. rubric:: Functions

.. autosummary::
   :toctree: _autosummary

   ~detops.nrc_header
   ~detops.create_detops
   ~detops.config2
